/* ROBOTS.H */
/* Declarations of structures and functions for the i-ROBOT Game.
 * 
 * By Siddharth Eswaran.
 */

#ifndef __ROBOTS_H
#define __ROBOTS_H

#include <time.h>

#define EMPTY 0
#define ROBOT 1
#define PLAYER 2
#define DEBRIS 3
#define TELEPORT 9 

#ifndef BOARDSIZE
#define BOARDSIZE 31 
#endif

#define MAXROBOTS 50
#define MAXTPORTS 20

typedef struct 
{
	int r,c;
}pair;

typedef struct _pnode
{
	pair p;
	struct _pnode *next,*prev;
}pnode;

typedef struct
{
	  char code;
	  pnode *ptr;
}object;

/* Global variables required in the game. */
extern object board[BOARDSIZE][BOARDSIZE];
extern pnode *robot_list;
#ifdef __TELEPORT
	extern pnode *teleports;
#else
	extern pair teleports[MAXTPORTS];
#endif
extern int R,T,moves,tpmoves,avaltp,robcount;
extern unsigned int cputime;
extern int FLAG;
extern char *error;
extern pair player;
extern time_t start,end;

/* Functions for implementing the algorithm */

int load(const char*); /* would be defined in load.c */
int randinit(); /* would be defined in load.c */
int moverobots(); /* would be defined in robots.c */
void move(pair,pair); /* would be defined in robots.c */
void empty(pair); /* would be defiiined in robots.c */
void telemove(); /* would be defined in robots.c */
void destroy(pair); /* would be defined in robots.c */
void statistics(); /* would be defined in statistics.c */
void updatetp(); /* would be defined in robots.c */
void gameplay(); /* would be defined in gameplay.c */

#endif
